@@ -15,8 +15,7 @@ class PDF::Annot
     use PDF::COS::TextString;
 
     # See [PDF Spec 1.7 table 8.15 - Entries common to all annotation dictionaries ]
-    my subset Name-Annot of PDF::COS::Name where 'Annot';
-    has Name-Annot $.Type is entry;
+    has PDF::COS::Name $.Type is entry where 'Annot';
     has PDF::COS::Name $.Subtype is entry(:required);
     has Numeric @.Rect is entry(:required);                     #| (Required) The annotation rectangle, defining the location of the annotation on the page in default user space units.
     has PDF::COS::TextString $.Contents is entry;               #| (Optional) Text to be displayed for the annotation or, if this type of annotation does not display text, an alternate description of the annotation’s contents in human-readable form
