@@ -1,5 +1,8 @@
+use PDF::FontStream;
 use PDF::COS::Stream;
+# See [PDF 320000 - Table 127 – Additional entries in an embedded font stream dictionary]
 class PDF::FontFile
+    does PDF::FontStream
     is PDF::COS::Stream {
     use PDF::COS::Name;
     use PDF::COS::Tie;
